summaryrefslogtreecommitdiff
path: root/editeng/inc/editeng/lrspitem.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'editeng/inc/editeng/lrspitem.hxx')
-rw-r--r--editeng/inc/editeng/lrspitem.hxx107
1 files changed, 53 insertions, 54 deletions
diff --git a/editeng/inc/editeng/lrspitem.hxx b/editeng/inc/editeng/lrspitem.hxx
index d0e03995a7..68a9fa5ba9 100644
--- a/editeng/inc/editeng/lrspitem.hxx
+++ b/editeng/inc/editeng/lrspitem.hxx
@@ -40,56 +40,55 @@ namespace rtl
// class SvxLRSpaceItem --------------------------------------------------
-/*
-[Beschreibung]
-Linker/Rechter Rand sowie Erstzeileneinzug
-
-SvxLRSpaceItem bietet zwei Schnittstellen zur Befragung des linken
-Randes und des Erstzeileneinzuges an. Die Get-Methoden liefern
-die Member zurueck, wie sie das Layout bisher auch erwartete:
-Der linke Rand verschiebt sich beim negativem Erstzeileneinzug
-nach links. Die SetTxt/GetTxt-Methoden setzen voraus, dass der
-linke Rand der 0-Punkt des Erstzeileneinzugs darstellt:
-
- UI UI LAYOUT UI/TEXT UI/TEXT (Wo?)
-SetTxtLeft SetTxtFirst GetLeft GetTxtLeft GetTxtFirst (Was?)
- 500 -500 0 500 -500 (Wieviel?)
+/* [Description]
+
+ Left/Right margin and first line indent
+
+ SvxLRSpaceItem offers two interfaces for views from the left margin and
+ first line indent. The get methods return the member, with the layout also
+ as expected: the left edge shifts to the negative first line indent to the
+ left. The SetTxt/Gettxt methods assume that the left side represents the
+ 0 coordinate for the first line indent:
+
+ UI UI LAYOUT UI/TEXT UI/TEXT (Where?)
+ SetTxtLeft SetTxtFirst GetLeft GetTxtLeft GetTxtFirst (What?)
+ 500 -500 0 500 -500 (How much?)
500 0 500 500 0
500 +500 500 500 +500
700 -500 200 700 -500
*/
-#define LRSPACE_16_VERSION ((USHORT)0x0001)
-#define LRSPACE_TXTLEFT_VERSION ((USHORT)0x0002)
-#define LRSPACE_AUTOFIRST_VERSION ((USHORT)0x0003)
-#define LRSPACE_NEGATIVE_VERSION ((USHORT)0x0004)
+#define LRSPACE_16_VERSION ((sal_uInt16)0x0001)
+#define LRSPACE_TXTLEFT_VERSION ((sal_uInt16)0x0002)
+#define LRSPACE_AUTOFIRST_VERSION ((sal_uInt16)0x0003)
+#define LRSPACE_NEGATIVE_VERSION ((sal_uInt16)0x0004)
class EDITENG_DLLPUBLIC SvxLRSpaceItem : public SfxPoolItem
{
- short nFirstLineOfst; // Erstzeileneinzug _immer_ relativ zu nTxtLeft
- long nTxtLeft; // wir spendieren einen USHORT
- long nLeftMargin; // nLeft oder der neg. Erstzeileneinzug
- long nRightMargin; // der unproblematische rechte Rand
+ short nFirstLineOfst; // First-line indent _always_ relative to nTxtLeft
+ long nTxtLeft; // We spend a sal_uInt16
+ long nLeftMargin; // nLeft or the negative first-line indent
+ long nRightMargin; // The unproblematic right edge
- USHORT nPropFirstLineOfst, nPropLeftMargin, nPropRightMargin;
- BOOL bAutoFirst : 1; // Automatische Berechnung der Erstzeileneinzugs
+ sal_uInt16 nPropFirstLineOfst, nPropLeftMargin, nPropRightMargin;
+ sal_Bool bAutoFirst : 1; // Automatic calculation of the first line indent
- void AdjustLeft(); // nLeftMargin und nTxtLeft werden angepasst.
+ void AdjustLeft(); // nLeftMargin and nTxtLeft are being adjusted.
public:
TYPEINFO();
- SvxLRSpaceItem( const USHORT nId );
+ SvxLRSpaceItem( const sal_uInt16 nId );
SvxLRSpaceItem( const long nLeft, const long nRight,
const long nTLeft /*= 0*/, const short nOfset /*= 0*/,
- const USHORT nId );
+ const sal_uInt16 nId );
inline SvxLRSpaceItem& operator=( const SvxLRSpaceItem &rCpy );
// "pure virtual Methoden" vom SfxPoolItem
virtual int operator==( const SfxPoolItem& ) const;
- virtual bool QueryValue( com::sun::star::uno::Any& rVal, BYTE nMemberId = 0 ) const;
- virtual bool PutValue( const com::sun::star::uno::Any& rVal, BYTE nMemberId = 0 );
+ virtual bool QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 ) const;
+ virtual bool PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId = 0 );
virtual SfxItemPresentation GetPresentation( SfxItemPresentation ePres,
SfxMapUnit eCoreMetric,
@@ -97,41 +96,41 @@ public:
String &rText, const IntlWrapper * = 0 ) const;
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const;
- virtual SfxPoolItem* Create(SvStream &, USHORT) const;
- virtual SvStream& Store(SvStream &, USHORT nItemVersion ) const;
- virtual USHORT GetVersion( USHORT nFileVersion ) const;
- virtual bool ScaleMetrics( long nMult, long nDiv );
- virtual bool HasMetrics() const;
+ virtual SfxPoolItem* Create(SvStream &, sal_uInt16) const;
+ virtual SvStream& Store(SvStream &, sal_uInt16 nItemVersion ) const;
+ virtual sal_uInt16 GetVersion( sal_uInt16 nFileVersion ) const;
+ virtual bool ScaleMetrics( long nMult, long nDiv );
+ virtual bool HasMetrics() const;
// Die "Layout-Schnittstelle":
- inline void SetLeft ( const long nL, const USHORT nProp = 100 );
- inline void SetRight( const long nR, const USHORT nProp = 100 );
+ inline void SetLeft ( const long nL, const sal_uInt16 nProp = 100 );
+ inline void SetRight( const long nR, const sal_uInt16 nProp = 100 );
- // abfragen / direktes setzen der absoluten Werte
+ // Query/direct setting of the absolute values
inline long GetLeft() const { return nLeftMargin; }
inline long GetRight() const { return nRightMargin;}
inline void SetLeftValue( const long nL ) { nTxtLeft = nLeftMargin = nL; }
inline void SetRightValue( const long nR ) { nRightMargin = nR; }
- inline BOOL IsAutoFirst() const { return bAutoFirst; }
- inline void SetAutoFirst( const BOOL bNew ) { bAutoFirst = bNew; }
+ inline sal_Bool IsAutoFirst() const { return bAutoFirst; }
+ inline void SetAutoFirst( const sal_Bool bNew ) { bAutoFirst = bNew; }
- // abfragen / setzen der Prozent-Werte
- inline void SetPropLeft( const USHORT nProp = 100 )
+ // Query/Setting the percentage values
+ inline void SetPropLeft( const sal_uInt16 nProp = 100 )
{ nPropLeftMargin = nProp; }
- inline void SetPropRight( const USHORT nProp = 100 )
+ inline void SetPropRight( const sal_uInt16 nProp = 100 )
{ nPropRightMargin = nProp;}
- inline USHORT GetPropLeft() const { return nPropLeftMargin; }
- inline USHORT GetPropRight() const { return nPropRightMargin;}
+ inline sal_uInt16 GetPropLeft() const { return nPropLeftMargin; }
+ inline sal_uInt16 GetPropRight() const { return nPropRightMargin;}
- // Die "UI/Text-Schnittstelle":
- inline void SetTxtLeft( const long nL, const USHORT nProp = 100 );
+ // The UI/text interface:
+ inline void SetTxtLeft( const long nL, const sal_uInt16 nProp = 100 );
inline long GetTxtLeft() const { return nTxtLeft; }
- inline void SetTxtFirstLineOfst( const short nF, const USHORT nProp = 100 );
+ inline void SetTxtFirstLineOfst( const short nF, const sal_uInt16 nProp = 100 );
inline short GetTxtFirstLineOfst() const { return nFirstLineOfst; }
- inline void SetPropTxtFirstLineOfst( const USHORT nProp = 100 )
+ inline void SetPropTxtFirstLineOfst( const sal_uInt16 nProp = 100 )
{ nPropFirstLineOfst = nProp; }
- inline USHORT GetPropTxtFirstLineOfst() const
+ inline sal_uInt16 GetPropTxtFirstLineOfst() const
{ return nPropFirstLineOfst; }
inline void SetTxtFirstLineOfstValue( const short nValue )
{ nFirstLineOfst = nValue; }
@@ -150,26 +149,26 @@ inline SvxLRSpaceItem &SvxLRSpaceItem::operator=( const SvxLRSpaceItem &rCpy )
return *this;
}
-inline void SvxLRSpaceItem::SetLeft( const long nL, const USHORT nProp )
+inline void SvxLRSpaceItem::SetLeft( const long nL, const sal_uInt16 nProp )
{
nLeftMargin = (nL * nProp) / 100;
nTxtLeft = nLeftMargin;
nPropLeftMargin = nProp;
}
-inline void SvxLRSpaceItem::SetRight( const long nR, const USHORT nProp )
+inline void SvxLRSpaceItem::SetRight( const long nR, const sal_uInt16 nProp )
{
nRightMargin = (nR * nProp) / 100;
nPropRightMargin = nProp;
}
inline void SvxLRSpaceItem::SetTxtFirstLineOfst( const short nF,
- const USHORT nProp )
+ const sal_uInt16 nProp )
{
nFirstLineOfst = short((long(nF) * nProp ) / 100);
nPropFirstLineOfst = nProp;
AdjustLeft();
}
-inline void SvxLRSpaceItem::SetTxtLeft( const long nL, const USHORT nProp )
+inline void SvxLRSpaceItem::SetTxtLeft( const long nL, const sal_uInt16 nProp )
{
nTxtLeft = (nL * nProp) / 100;
nPropLeftMargin = nProp;
@@ -40,56 +40,55 @@ namespace rtl
inline SvxLRSpaceItem& operator=( const SvxLRSpaceItem &rCpy );
- // "pure virtual Methoden" vom SfxPoolItem
+ // "pure virtual Methods" from SfxPoolItem
virtual int operator==( const SfxPoolItem& ) const;